@@ -47,7 +47,10 @@ def __print_info(func, ops = ''):
 
 # Floor
 def floor(x):
-    '''\nthis function returns the greatest integer less or equal to x\nit returns "None" if the argument is not valid'''
+    '''\nthis function returns the greatest integer less or equal to x\nit returns "None" if the argument is not valid
+    \nex1.\n>>> floor(-3.015)\n-4
+    \nex2.\n>>> floor(4.87)\n4
+    \nex3.\n>>> floor(7)\n7'''
 
     try:
         return int(x // 1)
@@ -58,7 +61,10 @@ def floor(x):
 
 # Ceil
 def ceil(x):
-    '''\nthis function returns the least integer greater or equal to x\nit returns "None" if the argument is not valid'''
+    '''\nthis function returns the least integer greater or equal to x\nit returns "None" if the argument is not valid
+    \nex1.\n>>> ceil(-3.015)\n-3
+    \nex2.\n>>> ceil(4.87)\n5
+    \nex3.\n>>> ceil(7)\n7'''
 
     try:
         if int(x) == x:
@@ -72,17 +78,15 @@ def ceil(x):
 
 # Fractional part
 def frac(x):
-    '''\nthis function returns the fractional part of a number as an integer\nit returns "None" if the argument is not valid'''
+    '''\nthis function returns the fractional part of a number as an integer\nit returns "None" if the argument is not valid
+    \nex1.\n>>> frac(12.13)\n13
+    \nex2.\n>>> frac(135.1010101)\n1010101'''
 
     try:
-        power = 10 ** int(len(str(float(x))))
+        power = 10 ** (len(str(x)) - len(str(int(x))) - 1)
         ix = int(x)
         x *= power
-        while x % 10 == 0:
-            x /= 10
-            power /= 10
-        else:
-            return int(x) - ix * int(power)
+        return int(x) - ix * int(power)
     except:
         return None
 
@@ -90,7 +94,10 @@ def frac(x):
 
 # Root
 def root(x, y = 2):
-    '''\ny is a number automatically set to 2\nthis function returns the yth root of x\nit returns "None" if 1 or more arguments are not valid'''
+    '''\ny is a number automatically set to 2\nthis function returns the yth root of x\nit returns "None" if 1 or more arguments are not valid
+    \nex1.\n>>> root(4)\n2.0
+    \nex2.\n>>> root(5, 3)\n1.7099759466766968
+    \nex3.\n>>> root(4, 4) == root(2, 2)\nTrue'''
 
     try:
         return x**(1/y)
@@ -101,7 +108,10 @@ def root(x, y = 2):
 
 # GCD
 def gcd(x, y):
-    '''this function returns the greatest common divisor of two numbers\nit returns "None" if 1 or more arguments are not valid'''
+    '''\nthis function returns the greatest common divisor of two numbers\nit returns "None" if 1 or more arguments are not valid
+    \nex1.\n>>> gcd(120, 88)\n8
+    \nex2.\n>>> gcd(33, 44)\n11
+    \nex3.\n>>> gcd(15, 16)\n1'''
 
     try:
         while y > 0:
@@ -114,35 +124,29 @@ def gcd(x, y):
 
 # LCM
 def lcm(x, y):
-    '''this function returns the least common multiple of two numbers\nit returns "None" if 1 or more arguments are not valid'''
+    '''\nthis function returns the least common multiple of two numbers\nit returns "None" if 1 or more arguments are not valid
+    \nex1.\n>>> lcm(3, 6)\n6
+    \nex2.\n>>> lcm(4, 22)\n44'''
 
     try:
-        if x > y:
-            greater = x
-        else:
-            greater = y
-
-        while True:
-            if((greater % x == 0) and (greater % y == 0)):
-                lcm_xy = greater
-                break
-            greater += 1
-
-        return lcm_xy
+        return int((x*y)/gcd(x,y))
     except:
         return None
 
 
 
 # Mod
-def mod(x, y = 10, z = 0):
-    '''\ny is an integer automatically set to 10\nz is an integer automatically set to 0\n
+def mod(x, y, z = 0):
+    '''\nz is an integer automatically set to 0\n
         \nthis function returns the solution to the equation
         \n      zk ≡ x (mod y)
         \nthe result will be k = "solution" (mod y) with "solution" returned
         \nthis function will return "None" if the equation has no solution, or if 1 or more arguments are not valid
         \nif z is missing or set to 0 this fuction will return
-        \n        x (mod y)'''
+        \n        x (mod y)
+        \nex1.\n>>> mod(7, 4, 8)\nNone
+        \nex2.\n>>> mod(7, 4, 5)\n3
+        \nex3.\n>>> mod(25, 10)\n5'''
     
     try:
         while True:
@@ -178,7 +182,9 @@ def mod(x, y = 10, z = 0):
 # Divisors
 def div(x, y = 1):
     '''\ny is an integer automatically set to 1\nthis function returns the number of divisors of x if y is 1 or missing
-        \nit returns the list of divisors of x if y is 2\nit returns "None" if 1 or more arguments are not valid'''
+        \nit returns the list of divisors of x if y is 2\nit returns "None" if 1 or more arguments are not valid
+        \nex1.\n>>> div(488)\n8
+        \nex2.\n>>> div(488, 2)\n[1, 2, 4, 8, 61, 122, 244, 488]'''
 
     try:
         count = 0
@@ -202,7 +208,9 @@ def div(x, y = 1):
 
 # Prime
 def prime(x):
-    '''\nthis function returns the xth prime number\nit returns "None" if the argument is not valid'''
+    '''\nthis function returns the xth prime number\nit returns "None" if the argument is not valid
+    \nex1.\n>>> prime(10)\n29
+    \nex2.\n>>> prime(8266)\n84857'''
 
     try:
         primelist = [2]
@@ -223,11 +231,17 @@ def prime(x):
 # Relatively Prime checker
 def rel(x, y = 0):
     '''\ny is an integer automatically set to 0
-    \nthis function returns "True" if x and y are relatively prime, it returns False if not, and it returns "None" if 1 or more arguments are not valid
-    \nif y is set to 0 or missing this function will return "True" if x is prime and "False" otherwise'''
+    \nthis function returns "True" if x and y are relatively prime, it returns "False" if not, and it returns "None" if 1 or more arguments are not valid
+    \nif y is set to 0 or missing this function will return "True" if x is prime and "False" otherwise
+    \nex1.\n>>> rel(91)\nFalse
+    \nex2.\n>>> rel(14, 27)\nTrue
+    \nex3.\n>>> rel(2, 120)\nFalse'''
     try:
+        if x == 0 or x == 1:
+            return False
+
         if y == 0:
-            for i in range(2, int(x**(1/2))):
+            for i in range(2, int(x**(1/2)) + 1):
                 if x % i == 0:
                     return False
                 else:
@@ -244,12 +258,13 @@ def rel(x, y = 0):
 
 
 # Primes less than a given number
-def pi(x, y=1):
-    '''\nthis function returns the number of primes less than x if y is 1 or missing\nthis function returns the number of primes between y argument and x otherwise\nit returns "None" if 1 or more arguments are not valid'''
+def pi(x, y = 1):
+    '''\ny is an integer automatically set to 1\nthis function returns the number of primes between y argument and x\nit returns "None" if 1 or more arguments are not valid
+    \nex1.\n>>> pi(1356)\n217
+    \nex2.\n>>> pi(180623)\n16392'''
 
     try:
         count = 0
-        
         for i in range(y, x):
             if rel(i) == True:
                 count += 1
@@ -261,7 +276,9 @@ def pi(x, y=1):
 
 # Factors
 def primefac(x):
-    '''\nthis function returns a list of x's prime factors\nit returns "None" if the argument is not valid'''
+    '''\nthis function returns a list of x's prime factors\nit returns "None" if the argument is not valid
+    \nex1.\n>>> primefac(120)\n[2, 2, 2, 3, 5]
+    \nex2.\n>>> primefac(13)\n[13]'''
     try:
         factors = []
 
@@ -290,7 +307,10 @@ def primefac(x):
 
 # Factorial
 def fac(x):
-    '''\nthis function returns argument factorial'''
+    '''\nthis function returns argument factorial
+    \nex1.\n>>> fac(6)\n720
+    \nex2.\n>>> fac(12)\n479001600
+    \nex2.\n>>> fac(0)\n1'''
     prod = 1
 
     for i in range(1, x + 1):
@@ -302,7 +322,9 @@ def fac(x):
 
 # Collatz
 def col(x):
-    '''\nthis function returns a list containing each step of the Collatz Conjecture check process\nit returns "None" if the argument is not valid'''
+    '''\nthis function returns a list containing each step of the Collatz Conjecture check process\nit returns "None" if the argument is not valid
+    \nex1.\n>>> col(7)\n[7, 22, 11, 34, 17, 52, 26, 13, 40, 20, 10, 5, 16, 8, 4, 2, 1]
+    \nex2.\n>>> col(170)\n[170, 85, 256, 128, 64, 32, 16, 8, 4, 2, 1]'''
 
     try:
         collist = []
@@ -311,7 +333,7 @@ def col(x):
             if x % 2 == 0:
                 x /= 2
             else:
-                x = (3*x + 1)/2
+                x = (3*x + 1)
         else:
             collist.append(int(x))
         return collist
@@ -322,7 +344,9 @@ def col(x):
 
 # Euler's Totient Function
 def tot(x):
-    '''\nthis function returns the number of integers between 1 and n that are relatively prime to n\nit returns "None" if the argument is not valid'''
+    '''\nthis function returns the number of integers between 1 and n that are relatively prime to n\nit returns "None" if the argument is not valid
+    \nex1.\n>>> tot(163)\n162
+    \nex2.\n>>> tot(2222)\n1000'''
 
     try:
         count = 0        
@@ -334,40 +358,104 @@ def tot(x):
         return None
 
 
-funcdict = {
-    'floor': floor,
-    'ceil': ceil,
-    'frac': frac,
-    'root': root,
-    'mod': mod,
-    'gcd': gcd,
-    'lcm': lcm,
-    'div': div,
-    'prime': prime,
-    'pi': pi,
-    'primefac': primefac,
-    'fac': fac,
-    'col': col,
-    'rel': rel,
-    'tot': tot
-}
+
+# Base Converter
+def base(x, y = 10, z = 2):
+    '''\ny is an integer automatically set to 10\nz is an integer automatically set to 2
+    \nthis function return x converted from base y to base z
+    \nif z is greater than 10 the result will have a space between each digit\nat the same time, if y is greater than 10, the input x must be a string with spaces between each digit\nit returns "None" if 1 or more arguments are not valid, or if x can't exist in base y
+    \nex1.\n>>> base(123)\n1111011
+    \nex2.\n>>> base(34, 8, 13)\n2 2
+    \nex3.\n>>> base('8 12', 17, 4)\n2110'''
+
+
+    count = []
+    xlist = []
+
+    # Separating digits
+    if y > 10:
+        for i in str(x):
+            if i != ' ':
+                count.append(i)
+            else:
+                if count != []:
+                    xlist.append(''.join(count))
+                    count = []
+                else:
+                    continue
+        xlist.append(''.join(count))
+        
+    else:
+        for i in str(x):
+            xlist.append(i)
+
+    
+    a = len(xlist)
+    base10 = int(''.join(xlist))
+    xlist = [int(i) for i in xlist]
+
+    # Checking Digits
+    for i in xlist:
+        if i < y:
+            continue
+        else:
+            return None
+
+    # Conversion to base 10
+    if y != 10:
+        base10 = 0
+        for i in range(a):
+            base10 += xlist[i] * y ** (a - i - 1)
+
+    # Conversion to base z
+    x = base10
+    basez_list = []
+    remain = 1
+    while x != 0:
+        remain = x % z
+        basez_list.append(remain)
+        x = x // z
+    basez = [str(basez_list[len(basez_list) - i - 1]) for i in range(len(basez_list))]
+
+    if z < 10:
+        return ''.join(basez)
+    else:
+        return ' '.join(basez)
 
 
 
 # Info
 def info(x = 0):
-    '''
-    run htam.info() to see general informations about htam functions
-    '''
+    '''\nrun htam.info() to see general informations about htam functions'''
 
-    # All Functions that takes 3 or 2 arguments respectively
-    arg3 = ['mod']
+    # Dictionary of all functions
+    funcdict = {
+        'floor': floor,
+        'ceil': ceil,
+        'frac': frac,
+        'root': root,
+        'mod': mod,
+        'gcd': gcd,
+        'lcm': lcm,
+        'div': div,
+        'prime': prime,
+        'pi': pi,
+        'primefac': primefac,
+        'fac': fac,
+        'col': col,
+        'rel': rel,
+        'tot': tot,
+        'base': base
+    }
+
+    # All Functions that takes 2 or 3 arguments respectively
     arg2 = ['root', 'div', 'gcd', 'lcm', 'pi', 'rel']
+    arg3 = ['mod', 'base']
 
     if x == 0:
         print(
             '\n' + __pack.upper() + '\n'
-            '\nver. 1.1.0\n '
+            '\nver. 1.2.0\n '
             '\nHere\'s a list of functions ' + __pack + ' can perform. \n'
             )
         for i in funcdict.keys():
